@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.0.4
+#www2sms.py v1.0.5
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -26,12 +26,14 @@
 import os, errno, pwd, sys, math, sqlite3, time, calendar, evolution, re, socket
 import ctypes, uuid, glib, gobject
 from PyQt4 import QtCore
-from PyQt4.QtGui import QApplication, QMainWindow, QDialog, QPushButton, QMessageBox
+from PyQt4.QtGui import QApplication, QMainWindow, QDialog, QPushButton, QMessageBox, QPixmap
 from www2sms_gui_main import Ui_MainWindow
 from www2sms_gui_widget_account import Ui_FormAccount
 from www2sms_gui_dialog_progress import Ui_Form_Progress
 import www2sms_providers
 
+
+VERSION = "v1.0.5"
 USER = pwd.getpwuid(os.getuid())[0]
 CONFIG_DIR = "/home/%s/MyDocs/www2sms" %(USER)
 
@@ -52,6 +54,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 		self.ui = Ui_MainWindow()
 		self.ui.setupUi(self)
 		# Setup GUI elements
+		self.ui.label_www2sms.setText('www2sms')
+		self.ui.label_www2sms_version.setText(VERSION)
+		pixmap = QPixmap('/usr/share/pixmaps/www2sms.png')
+		self.ui.label_www2sms_logo.setPixmap(pixmap)
 		# Get the phone book
 		self.my_phone_book = self.get_contacts()
 		# Populate the contact list
